@@ -14,4 +14,4 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.discovery.log_skeleton import variants, trace_skel, outputs
+from pm4py.algo.discovery.log_skeleton import variants, trace_skel
