@@ -18,7 +18,7 @@ from enum import Enum
 
 from pm4py.algo.filtering.common.timestamp.timestamp_common import get_dt_from_string
 from pm4py.objects.conversion.log import converter as log_converter
-from pm4py.objects.log.log import EventLog, EventStream
+from pm4py.objects.log.obj import EventLog, EventStream
 from pm4py.util import exec_utils
 from pm4py.util.constants import PARAMETER_CONSTANT_TIMESTAMP_KEY
 from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
