@@ -17,7 +17,7 @@
 import random
 from copy import copy
 
-from pm4py.objects.log.log import EventStream, EventLog
+from pm4py.objects.log.obj import EventStream, EventLog
 
 
 def sample_stream(event_log, no_events=100):
