@@ -21,6 +21,7 @@ PARAMETER_CONSTANT_START_TIMESTAMP_KEY = 'pm4py:param:start_timestamp_key'
 PARAMETER_CONSTANT_CASEID_KEY = 'case_id_glue'
 PARAMETER_CONSTANT_RESOURCE_KEY = 'pm4py:param:resource_key'
 PARAMETER_CONSTANT_TRANSITION_KEY = 'pm4py:param:transition_key'
+PARAMETER_CONSTANT_GROUP_KEY = 'pm4py:param:group_key'
 
 GROUPED_DATAFRAME = 'grouped_dataframe'
 RETURN_EA_COUNT_DICT_AUTOFILTER = 'return_ea_count_dict_autofilter'
@@ -46,3 +47,14 @@ DEFAULT_EVENT_INDEX_KEY = "@@event_index"
 DEFAULT_FLOW_TIME = "@@flow_time"
 
 DEFAULT_ENCODING = "utf-8"
+
+from enum import Enum
+
+
+class AvailableSerializations(Enum):
+    EVENT_LOG = "event_log"
+    DATAFRAME = "dataframe"
+    PETRI_NET = "petri_net"
+    PROCESS_TREE = "process_tree"
+    BPMN = "bpmn"
+    DFG = "dfg"
