@@ -21,7 +21,11 @@ import pydotplus
 
 from pm4py.util import exec_utils
 from pm4py.visualization.common.utils import human_readable_stat
-from pm4py.visualization.parameters import Parameters
+from enum import Enum
+
+
+class Parameters(Enum):
+    FORMAT = "format"
 
 
 def get_corr_hex(num):
@@ -150,7 +154,7 @@ def apply(heu_net, parameters=None):
         else:
             n = pydotplus.Node(name=node_name, shape="box", style="filled",
                                label=node_name + " (" + human_readable_stat(heu_net.sojourn_times[
-                                                                                node_name]) + ")" if node_name in heu_net.sojourn_times else "0s",
+                                                                                node_name]) + ")" if node_name in heu_net.sojourn_times else node_name + " (0s)",
                                fillcolor=node.get_fill_color(graycolor),
                                fontcolor=node.get_font_color())
         corr_nodes[node] = n
@@ -211,22 +215,23 @@ def apply(heu_net, parameters=None):
             for node_name in effective_sa_list:
                 sa = corr_nodes_names[node_name]
                 if type(heu_net.start_activities[index]) is dict:
-                    if is_frequency:
-                        occ = heu_net.start_activities[index][node_name]
-                        this_pen_width = 1.0 + math.log(1 + occ) / 11.0
-                        if heu_net.net_name[index]:
-                            e = pydotplus.Edge(src=start_i, dst=sa,
-                                               label=heu_net.net_name[index] + " (" + str(occ) + ")",
-                                               color=heu_net.default_edges_color[index],
-                                               fontcolor=heu_net.default_edges_color[index], penwidth=this_pen_width)
+                    occ = heu_net.start_activities[index][node_name]
+                    if occ >= heu_net.min_dfg_occurrences:
+                        if is_frequency:
+                            this_pen_width = 1.0 + math.log(1 + occ) / 11.0
+                            if heu_net.net_name[index]:
+                                e = pydotplus.Edge(src=start_i, dst=sa,
+                                                   label=heu_net.net_name[index] + " (" + str(occ) + ")",
+                                                   color=heu_net.default_edges_color[index],
+                                                   fontcolor=heu_net.default_edges_color[index], penwidth=this_pen_width)
+                            else:
+                                e = pydotplus.Edge(src=start_i, dst=sa, label=str(occ),
+                                                   color=heu_net.default_edges_color[index],
+                                                   fontcolor=heu_net.default_edges_color[index], penwidth=this_pen_width)
                         else:
-                            e = pydotplus.Edge(src=start_i, dst=sa, label=str(occ),
+                            e = pydotplus.Edge(src=start_i, dst=sa, label=heu_net.net_name[index],
                                                color=heu_net.default_edges_color[index],
-                                               fontcolor=heu_net.default_edges_color[index], penwidth=this_pen_width)
-                    else:
-                        e = pydotplus.Edge(src=start_i, dst=sa, label=heu_net.net_name[index],
-                                           color=heu_net.default_edges_color[index],
-                                           fontcolor=heu_net.default_edges_color[index])
+                                               fontcolor=heu_net.default_edges_color[index])
                 else:
                     e = pydotplus.Edge(src=start_i, dst=sa, label=heu_net.net_name[index],
                                        color=heu_net.default_edges_color[index],
@@ -243,21 +248,22 @@ def apply(heu_net, parameters=None):
             for node_name in effective_ea_list:
                 ea = corr_nodes_names[node_name]
                 if type(heu_net.end_activities[index]) is dict:
-                    if is_frequency:
-                        occ = heu_net.end_activities[index][node_name]
-                        this_pen_width = 1.0 + math.log(1 + occ) / 11.0
-                        if heu_net.net_name[index]:
-                            e = pydotplus.Edge(src=ea, dst=end_i, label=heu_net.net_name[index] + " (" + str(occ) + ")",
-                                               color=heu_net.default_edges_color[index],
-                                               fontcolor=heu_net.default_edges_color[index], penwidth=this_pen_width)
+                    occ = heu_net.end_activities[index][node_name]
+                    if occ >= heu_net.min_dfg_occurrences:
+                        if is_frequency:
+                            this_pen_width = 1.0 + math.log(1 + occ) / 11.0
+                            if heu_net.net_name[index]:
+                                e = pydotplus.Edge(src=ea, dst=end_i, label=heu_net.net_name[index] + " (" + str(occ) + ")",
+                                                   color=heu_net.default_edges_color[index],
+                                                   fontcolor=heu_net.default_edges_color[index], penwidth=this_pen_width)
+                            else:
+                                e = pydotplus.Edge(src=ea, dst=end_i, label=str(occ),
+                                                   color=heu_net.default_edges_color[index],
+                                                   fontcolor=heu_net.default_edges_color[index], penwidth=this_pen_width)
                         else:
-                            e = pydotplus.Edge(src=ea, dst=end_i, label=str(occ),
+                            e = pydotplus.Edge(src=ea, dst=end_i, label=heu_net.net_name[index],
                                                color=heu_net.default_edges_color[index],
-                                               fontcolor=heu_net.default_edges_color[index], penwidth=this_pen_width)
-                    else:
-                        e = pydotplus.Edge(src=ea, dst=end_i, label=heu_net.net_name[index],
-                                           color=heu_net.default_edges_color[index],
-                                           fontcolor=heu_net.default_edges_color[index])
+                                               fontcolor=heu_net.default_edges_color[index])
                 else:
                     e = pydotplus.Edge(src=ea, dst=end_i, label=heu_net.net_name[index],
                                        color=heu_net.default_edges_color[index],
